@@ -50,14 +50,14 @@ public:
      * @param gameData The related GameData object.
      * @param parent The parent widget.
      */
-    GameView(GameScene * gameScene, GameData * gameData, QWidget * parent = 0);
-    ~GameView();
+    GameView(GameScene * gameScene, GameData * gameData, QWidget * parent = nullptr);
+    ~GameView() override;
 
     /**
      * Items where added to the scene and should now be layouted.
      *
      * @param gameItems The items of which the positions should be updated. */
-    void updateItemsPosition(QList<GameItem *> gameItems);
+    void updateItemsPosition(const QList<GameItem *> &gameItems);
 
     /**
      * Updates the whole widget.
@@ -264,11 +264,11 @@ public slots:
 protected:
     /**
      * Override from QGraphicsView. */
-    void resizeEvent(QResizeEvent * event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent * event) override;
 
     /**
      * Override from QGraphicsView. */
-    void mousePressEvent(QMouseEvent * mouseEvent) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent * mouseEvent) override;
 
 signals:
     /**
@@ -351,7 +351,7 @@ private:
      * Updates the images of the items.
      *
      * @param gameItem The items of which the images should be updated. */
-    void updateItemsImages(QList<GameItem *> gameItems);
+    void updateItemsImages(const QList<GameItem *> &gameItems);
 
     /**
      * Updates the order of the items. */
